All language subtitles for Boston.Blue.S01E03.1080p.HEVC.x265-MeGusta[EZTVx.to].es

af Afrikaans
ak Akan
sq Albanian
am Amharic
ar Arabic
hy Armenian
az Azerbaijani
eu Basque
be Belarusian
bem Bemba
bn Bengali
bh Bihari
bs Bosnian
br Breton
bg Bulgarian
km Cambodian
ca Catalan
ceb Cebuano
chr Cherokee
ny Chichewa
zh-CN Chinese (Simplified)
zh-TW Chinese (Traditional)
co Corsican
hr Croatian
cs Czech
da Danish
nl Dutch
en English
eo Esperanto
et Estonian
ee Ewe
fo Faroese
tl Filipino
fi Finnish
fr French
fy Frisian
gaa Ga
gl Galician
ka Georgian
de German
el Greek
gn Guarani
gu Gujarati
ht Haitian Creole
ha Hausa
haw Hawaiian
iw Hebrew
hi Hindi
hmn Hmong
hu Hungarian
is Icelandic
ig Igbo
id Indonesian
ia Interlingua
ga Irish
it Italian
ja Japanese
jw Javanese
kn Kannada
kk Kazakh
rw Kinyarwanda
rn Kirundi
kg Kongo
ko Korean
kri Krio (Sierra Leone)
ku Kurdish
ckb Kurdish (Soranî)
ky Kyrgyz
lo Laothian
la Latin
lv Latvian
ln Lingala
lt Lithuanian
loz Lozi
lg Luganda
ach Luo
lb Luxembourgish
mk Macedonian
mg Malagasy
ms Malay
ml Malayalam
mt Maltese
mi Maori
mr Marathi
mfe Mauritian Creole
mo Moldavian
mn Mongolian
my Myanmar (Burmese)
sr-ME Montenegrin
ne Nepali
pcm Nigerian Pidgin
nso Northern Sotho
no Norwegian
nn Norwegian (Nynorsk)
oc Occitan
or Oriya
om Oromo
ps Pashto
fa Persian
pl Polish
pt-BR Portuguese (Brazil) Download
pt Portuguese (Portugal)
pa Punjabi
qu Quechua
ro Romanian
rm Romansh
nyn Runyakitara
ru Russian
sm Samoan
gd Scots Gaelic
sr Serbian
sh Serbo-Croatian
st Sesotho
tn Setswana
crs Seychellois Creole
sn Shona
sd Sindhi
si Sinhalese
sk Slovak
sl Slovenian
so Somali
es Spanish
es-419 Spanish (Latin American)
su Sundanese
sw Swahili
sv Swedish
tg Tajik
ta Tamil
tt Tatar
te Telugu
th Thai
ti Tigrinya
to Tonga
lua Tshiluba
tum Tumbuka
tr Turkish
tk Turkmen
tw Twi
ug Uighur
uk Ukrainian
ur Urdu
uz Uzbek
vi Vietnamese
cy Welsh
wo Wolof
xh Xhosa
yi Yiddish
yo Yoruba
zu Zulu

Original subtitles

Dê-me um like e inscreva-se no YouTube: -- Bytechmx --

♪ Jogue mãos e anéis ♪

♪ Ele vai longe, mas não é jogando bem ♪

♪ Eles têm gelo em seus rosários ♪

♪ Eles são tão reais, encontrando capital em Cristo...♪

- -LENA: Uh.

Que?

Eu não pensei que você fosse do tipo selfie.

DANNY: Bem, às vezes eu abro exceções.

-Você faz isso? Para quem? -Hum-hmm.

Alguém em Nova York.

Alguém especial?

mmm, acho que é tudo o que vou lhe dar. Por agora.

Ah, bom.

-Seja assim. -Hum-hmm.

Tudo bem, vamos aqui, logo na esquina.

-Bom.

Lena: É um barco de recreio histórico.

Leve os turistas ao redor do porto para conhecer locais famosos da Revolução Americana.

-DANNY: Genial.

Temos alguns barcos como este em Nova York,

exceto que não temos todas as fantasias de Samuel Adams.

Vim aqui uma vez para um encontro.

Que? O que aconteceu com o menino?

Ah, nós namoramos por anos, e então, uh, colocamos

minha vida esperando por ele, então ele percebeu

Não éramos o casal certo e terminamos comigo.

-Parece um cara legal. -Hum.

Lena: Olá.

Foi este quem encontrou o corpo?

Obrigada.

detetive Plata, detetive Reagan.

Prazer em conhecê-lo, senhor...

-Tommy. -Tommy.

Conte-nos o que aconteceu.

Estávamos preparando a primeira turnê quando a vi...

preso lá.

Sacalla.

HARPER: Nos conhecemos em um bar.

:Ele parecia legal.

Normalmente eu não faria

casa com ele, mas eu fiz.

Acho que ele colocou alguma coisa na minha bebida.

A próxima coisa que me lembro é que estava amarrado.

Eu disse não.

Tentei fazê-lo parar.

-Mas ele não fez. -Ok, chega.

Ele é uma vítima infinitamente compreensiva.

Ela é professora.

O depoimento da polícia será útil, mas é

É o seu testemunho que trará um estuprador

rua perigosa por muito tempo.

Qual é o problema, Bobby?

Foi descoberto que Harper,

A vítima costumava fazer pornografia.

Pornô de escravidão em que ela estava amarrada,

correspondendo ao que ela disse que aconteceu durante o ataque.

A violenta agressão sexual que a mandou para o hospital.

Sim, mas também dá credibilidade ao

Argumento de consentimento da defesa.

Então, o que é esse vídeo?

um ato? De qualquer forma, temos que fazer uma oferta por um

contravenção que não inclui você no registro de agressores sexuais.

Se formos a julgamento, a defesa

usará seu passado para

desacreditá-la perante o júri e funcionará.

Você precisa se declarar culpado de um crime. Do que

Caso contrário, deixaremos um predador violento na rua.

Se formos a julgamento, o passado

da vítima será tornada pública.

Perca e a teremos arrastado pela lama em vão.

Mas é claro que é seu

decisão, Senhora Promotora Distrital.

Não, não é.

Depende dela.

Polícia de Boston! Verificação de bem-estar!

O Murray Bennett?

Eu vou entrar aqui.

MULHER: Ah, obrigada por ter vindo.

Murray me deu uma chave reserva para emergências, mas

quando ele não respondeu, ela ficou com muito medo de entrar sozinha.

Você fez a coisa certa ao nos ligar, Sra. Katz.

Murray mora sozinho?

-Hum-hmm. -Ele não está aqui.

Ok, então vamos chamar um Alerta Prata.

: Alerta Prata? Oh, não, não, Murray tem apenas 24 anos.

Há quanto tempo ele está desaparecido?

Não apareceu porque...

hora do quebra-cabeça

esta manhã, e.

.

. Não, eu sei o que você está pensando, mas ele nunca perderia isso. Ele sempre ligará se estiver ocupado ou se a caça estiver indo bem. Murray é um caçador?

Ah, caçador de tesouros. Na Internet.

Há um lugar chamado Bullseye.

Ganhou um prêmio de 20.

000 dólares no mês passado.

Desculpe, senhora, temos que ir.

Ah, não, por favor. Tenho a pior sensação sobre isso.

Ficaremos de olho em Murray.

Tudo ficará bem, eu prometo.

Obrigada.

Tenha um bom dia, senhora.

Cara, por que você disse que ficaríamos de olho nesse cara?

Não somos detetives. Não é nosso trabalho.

Eu não sei, cara. Ela é uma senhora mais velha. Eu me senti mal.

Vamos ficar de olho nesse cara

enquanto patrulhamos, ok?

Sara: Sinto muito, Phoebe.

Tentei nos tirar de casa a tempo.

Não, você estava ocupado ao telefone com seu trabalho.

Tudo bem. É que estou muito atrasado.

-Foi uma manhã movimentada.

-Sim, bem, explique isso ao diretor Martínez, porque

Eles vão me avisar com atraso, então...

Ok, olhe, você está preso com sua namorada idiota.

pai enquanto ele estiver fora da cidade. Eu entendo.

Não, você não quer, então...

Nem se preocupe em tentar, ok?

DANNY: Bem ali em cima.

Lena: Muito bom, mal havia

apodreceu, então não ficou muito tempo na água.

Sem sinais visíveis de trauma.

Esperançosamente, você tem alguma identificação. sobre ela em algum lugar.

Vai!

Caranguejo.

Alergia a marisco?

-Não é engraçado. -

Meu avô me disse para nunca confiar

Você pode levar sua casa com você.

Bem, agora você está em Boston. Isso é metade da nossa comida.

Tudo aqui são frutos do mar.

Bolos de caranguejo, rolinhos de lagosta, ostras sem casca.

E acho que não foi o marisco que a matou.

"Orca."

Heroína.

Não, esse é um tipo de peixe completamente diferente.

♪

RODGERS: Ei, traga todas essas pessoas de volta.

Atrás.

Com licença.

Sinto muito, posso ajudá-lo?

Sargento Brian Rodgers, Unidade Antidrogas.

Sua identificação

a vítima? Não. O corpo ficou muito tempo na água.

Isso vai demorar um pouco. Porque?

Porque este é o meu caso.

-Vem de novo? -Você encontrou um saco de

heroína de marca no bolso da vítima.

Algo chamado baleia assassina.

Está relacionado a pesquisas de longo prazo

do DCU, então nós assumiremos, detetive.

Bem, isso é interessante, chefe.

porque desde quando diabos o Narco superou o Major Case?

Olha, eu sei que os patrões moveram o céu e

terreno para você contratar BPD, mas

Isso não significa que eu tenha que me importar.

Bem, o que diabos você está tentando dizer?

-Olha, eu sei quem você é. -Hum-hmm.

Papai não é o comissário aqui.

Na verdade, você tem que seguir as regras.

Sim, e se você realmente soubesse

quem sou eu, você não falaria assim.

-Oh sim? -Hum-hmm.

Lena: Rodgers.

Olá, Lee.

É bom ver você.

Você também.

Este é Danny Reagan. meu novo parceiro.

Danny, este é Brian Rodgers. meu antigo parceiro

Ah, nós nos conhecemos.

Lena: Sim, isso não vai funcionar.

Nenhum de vocês desiste, certo?

-É o meu caso. -Não, é o nosso caso.

Eu entendo.

AMBOS: Para quem você está ligando?

sara: Desculpe pelo atraso, Lena.

Mas só porque você é minha irmã não significa

Você pode ligar para meu escritório quando tiver algum problema.

Com certeza sim.

Você ouviu falar sobre Jane Doe

O que tiramos do porto esta manhã?

Há alguma controvérsia

sobre de quem é o caso.

O legista disse que não havia água

seus pulmões, então ele não se afogou.

Causa da morte?

Overdose aguda de opioides.

Ela estava morta antes de entrar na água.

O que significa que seu corpo foi abandonado,

o que significa que pertence ao Mayor Case.

Não, ele teve uma overdose de uma mistura de

marca de fentanil e heroína chamada Killer Whale.

A Unidade de Controle de Drogas está preparando um

caso contra o distribuidor, um cara chamado Mitchell Edgars.

Houve um aumento nas overdoses este mês.

-Ele está por trás disso? -RODGERS: Sim,

e se Major Case começar a funcionar como um

touro em uma loja de porcelana, isso vai assustar

Edgars e isso arruinará toda a nossa investigação.

Tenho certeza de que ambos já trabalhamos em casos de drogas antes.

RODGERS: Ok, bem, estamos trabalhando de acordo com

as novas diretrizes policiais de baixo impacto, então...

Queremos manter isso em casa.

Me desculpe, o que?

Minimizamos o impacto negativo na comunidade.

Ou seja, quanto menos detenções por drogas de baixo nível, melhor.

Mantém os viciados fora do sistema.

E você também vende drogas para eles?

Isso é o suficiente. Reagan está certo.

Esta é uma morte desacompanhada em uma área turística popular.

É um caso importante.

Mas também quero que o DCU esteja envolvido.

Esta será uma investigação conjunta.

Vocês três trabalharão juntos no

Unidade de Casos Graves. Entendido?

Sim, senhora.

Entendido.

10-4, chefe.

Você sabe, é uma pena que vocês dois nunca estiveram juntos.

Todos vocês têm essa vibração.

É por isso que você nos faz trabalhar com o DCU?

Você diz que não namora casais. Vocês não são mais parceiros.

Lena: Uau.

Você deveria saber...

Ele não foi o próximo na reunião desta manhã.

Não, ele fez tudo o que pôde para estar na cena do crime.

Porque ele "ama" você.

-Você é um merda. -Sim. Eu sei.

Agora, por favor, descubra quem é

espalhando esse veneno em nossa cidade, ok?

-Sim, senhora. -Obrigado.

-Tem certeza que não quer um café? -Eu não estou bem.

Cara, esse site de caça ao tesouro é muito legal.

Eles publicam um novo no primeiro dia de cada mês.

Você pode ganhar dinheiro, prêmios.

-Esse garoto ganhou um jet ski. -Oh.

E há uma foto de Murray Bennett vencendo

o prêmio de $ 20.000. -

20k. Isso é dinheiro de verdade.

Na verdade, eu adorei essas coisas.

Eu costumava ser um nerd.

Até joguei cartografia online, cara.

Não há nada mais nerd do que jogos de mapas, cara.

O que você quer dizer com "costumava ser"?

Você não pode falar, irmão.

Os esportes fantásticos são apenas D&D com atletas.

-É a mesma coisa. -Espere, espere, espere.

Você está tentando arranjar uma briga agora?

O que você está fazendo?

Cara, eles realmente não estão entendendo isso.

Alguém postou a última pista aqui nos comentários.

"Onde a água sussurra numa dança suave, no

jardim de Harvard, reside o olhar de um mestre."

Você realmente acha que Murray Bennett está desaparecido?

A Sra. Katz parece pensar assim.

A gente leva para Pessoas Desaparecidas, sabe, responde e denuncia?

Ainda não se passaram 24 horas.

O MPU simplesmente dirá que não há caso.

Prometi à Sra. Katz que encontraríamos Murray.

Sr. Cartografia, vamos.

Basta ler a pista mais uma vez.

Talvez, talvez, se resolvermos o

procure, talvez encontremos Murray.

"Onde a água sussurra numa dança suave, no

jardim de Harvard, reside o olhar de um mestre."

-Acho que sei onde fica. -Não, você não.

Além disso, Harvard está fora do nosso raio de patrulha.

Não, "Jardim Harvard".

Está no arboreto. Planície da Jamaica, que é...

Tecnicamente, no nosso raio de patrulha, sim.

Você quer verificar?

Para Murray?

Para Murray.

Ainda iremos a julgamento na próxima semana?

Já me inscrevi para uma sub para cobrir minhas aulas.

É sobre isso que queremos conversar com você, Harper.

MULLINS: Ouvimos sobre sua carreira anterior.

Filmes adultos.

Oh.

Eh...

Ele tinha 22 anos e precisava de dinheiro para continuar estudando.

Eu deveria ter te contado. Eu não achei que isso importasse.

Você não nos deve uma explicação.

Só queremos ter certeza de que

entender as ramificações do seu caso.

-O que você quer dizer?

-MULLINS: Aprendemos isso com a defesa durante a descoberta.

Eles vão usar isso contra você.

HARPER: Sou professor do ensino médio.

Isso não pode sair. Isso vai me arruinar.

Mas poderíamos oferecer um acordo ao seu agressor

de culpa, caso em que ele não teria que testemunhar.

Simplesmente teria que ser um crime inregistrável.

Ele amarrou você, pelo que poderia ser um crime de cárcere privado.

-Mas não estupro? -MAE: Isso mesmo.

Eu poderia sair em 12 meses sem qualquer

agressão sexual em seu histórico.

Eu farei isso.

Eu vou testemunhar.

Ele tirou tudo de mim.

Não posso deixá-lo fazer isso com mais ninguém.

MULLINS: Acho que você não entende.

O promotor distrital. pode prestar depoimento mesmo sem o consentimento da vítima.

Se formos a julgamento, provavelmente não vencerás.

Sua credibilidade perante o júri

Isso prejudicará o caso e tornará público seu passado.

Não vou deixá-lo escapar impune.

-MULLINS: Não podemos... -Você a ouviu.

Nenhum acordo judicial.

Levaremos este caso a julgamento.

MULLINS: Se perdermos,

então ele não cumprirá nenhuma sentença.

Ele caminha.

Bem, então é melhor não perdermos.

Muito bem, obrigado.

Esse era o capitão do porto.

Ele está trabalhando com a Guarda Costeira e

o Serviço Meteorológico para descobrir

onde o corpo de Jane Doe estava na água.

Aparentemente houve algumas marés

muito grande, tornando difícil dizer.

- Então este é Mitchell Edgars? -Sim.

-Ele parece um vilão. -É porque é.

Essa é minha mesa antiga?

Hummm.

Ainda tem o amassado onde você o chutou.

Você ainda tem sua reserva Twix porque não é

ele pode confiar em você para salvá-los em sua própria área de trabalho?

-Agora é a mesa do Danny.

Oh sim?

Ups.

Vazio.

Você ainda não confia nele com seu Twix, hein?

O que, uh, o grande Danny Reagan não está por aí?

Corresponder às expectativas de Nova York?

Tire os pés da mesa.

O que você está fazendo?

Qual é o seu verdadeiro problema com ele?

Eu conheço o tipo dele.

Legado policial, ele acredita que pode fazer o que quiser.

-Ele não é como nós. -Você esqueceu que minha mãe é

o promotor distrital? e minha irmã é a

superintendente -e meu irmão é policial? -Você não se levantou como ele.

Antes de sua mãe se casar novamente,

Você nunca conheceu seu pai, como eu.

Você sempre teve algo a provar.

Bem, obrigado por mencionar casualmente meu trauma de infância.

É para isso que servem os ex-casais.

Falando nisso, eu estive, uh...

Pensando na lista de regras que

tivemos quando cavalgamos juntos. -Brian...

Vamos, Lee. Não somos mais parceiros.

Apenas um encontro, veja onde vai.

Não pode.

Você está namorando alguém?

Não.

Tire sua bunda da minha cadeira.

Você conseguiu mais alguma coisa do legista?

Sim, a vítima é uma mulher local com

Antecedentes menores, principalmente posse.

28 anos. Katleen Sullivan.

Essa é a Kathy? Irmã de Sully?

¿Mattapan Sully ou Sully de Dorchester?

Dorchester.

Quantos Sullys vocês dois conhecem?

-LENA: Cinco. -RODGERS: Quatro.

Este é um IC antigo nosso.

Isso significa que precisamos verificar com o gerente

informante e informá-lo que entraremos em contato com ele novamente.

DANNY: Ok, mas se o IC souber de alguma coisa, é possível.

que não temos tempo para esperar pela papelada.

RODGERS: Odeio dizer isso, mas concordo.

Podemos arquivar os papéis mais tarde.

Acho que ele simplesmente concordou comigo.

Olá?

Esta é Sarah Silver.

Ah, olá.

Como está indo a festa do pijama?

Não, ele viu Becky.

Phoebe disse que eles iriam

direto para sua casa depois da escola.

Eles ainda não estão lá?

Cachorro.

Então a Becky disse que eles estavam na casa da Phoebe?

Não, não. E você já tentou ligar para ela?

Bem. Bem.

Vou tentar com Phoebe. e entrarei em contato com você.

Sim.

: Vamos, contesta.

Levantar. Levantar.

Levantar. Droga, Phoebe, onde você está?

- -Preciso acompanhar.

Patrick Sullivan, Sully, era um viciado.

Ele tentou manter seu hábito.

E quando ele ficou limpo, nós o selecionamos como nosso IC.

Não o vejo há um ano.

Ei, vá brincar um pouco, ok?

-Detetives. -LENA: Sully.

Um minuto se passou.

Esse é Grayson? Ficou tão grande.

-Sim. -Você parece bem.

Tenho comido boxe saudável para ficar em forma.

Então, como vai? Quem é esse?

Novo parceiro.

Isso é desconfortável.

DANY: Humm.

Sully, temos más notícias.

É sua irmã.

Sinto muito.

Estou sóbrio há 18 meses.

Recuperei meu filho, estou fazendo o

programa, estou fazendo os passos, mas você...

Você não pode vencer a Maldição Sullivan.

-Vamos, Sully. -É verdade.

O vício levou meu pai, os pais dele antes dele, mas...

Kathy e eu deveríamos quebrar a corrente.

Sua irmã também estava sóbria?

SULLY: Foi o que pensei.

Ele acabou de receber seu chip de seis meses.

Detesto perguntar, Sully. Mas você sabe

Quem comprou para ela a droga que a matou?

Você já mencionou algo chamado Orca ou um cara chamado Mitchell Edgars?

-Eu não tenho certeza.

Que tal uma conexão de porta?

Eu não sei, ok? Eu não estou na vida.

RODGERS: Ok, ok, apenas...

Olha, avise-nos se ouvir alguma coisa, ok?

Sim claro.

Manchar.

Não deixe que isso afete sua sobriedade.

Você sabe que não é o que Kathy gostaria.

♪ É assim que fazemos ♪

♪ Isso, é isso, é assim que fazemos ♪

♪ Sim ♪

♪ Permita-me me apresentar ♪

♪ Sim, estou prestes a mudar o jogo... ♪

-Você quer um pouco? -Estou bem.

♪ Porque faço com que pareça fácil fazer o que quero, quando quero ♪

♪ Para 'sheezy, sim, relaxando'... ♪

Ah, não, obrigado.

♪ Agora estou no teto, sim ♪

♪ Relaxando, como você se sente? ♪

♪ Tudo o que faço é como um em um milhão ♪

♪ Eu sou aquele, eu sou aquele...♪

Polícia de Boston!

Mãos ao alto!

Você também, John Oliver.

Oh meu Deus, pare!

Ela é namorada do meu pai.

Não se preocupe, não é tão sério.

Sara: É muito sério.

Eu poderia prender você agora mesmo.

Consumo de álcool por menores,

conduta sexual inadequada com um menor.

Quantos anos você tem?

-Não estávamos fazendo nada!

-Sugiro que você saia daqui agora mesmo antes que eu mude de ideia.

Phoebe, Becky, venham comigo.

Mitchell Edgars tem três tenentes.

Praias de Jason, Marco Alves, Leonardo Leroy.

E então, abaixo deles, as crianças de rua.

Não havia como Kathy comprar diretamente de Edgars ou dos outros três, então começamos com

esses caras. -

Ah, eu tenho que atender isso. Eu voltarei.

Detetive Plata.

O que exatamente está impedindo você de trazer esses

cinco palhaços e fazê-los denunciar seus chefes?

A ACLU, para começar.

Não é de surpreender que eu pudesse virar qualquer um deles em uma hora.

Bem, não podemos todos ser Danny Reagan.

Não, não podemos, mas pelo menos

Você poderia tentar agir como um policial.

Lena: Você está falando sério?

Na verdade?

Não posso deixar vocês dois por 60 segundos?

Esse era o capitão do porto.

Eu descobri de onde veio o corpo dele.

-Onde? -Bem aqui.

O mesmo porto onde

barco turístico, por isso não ficou à deriva.

Naquela noite houve uma maré turbulenta devido a uma

tempestade ao largo da costa, então a única maneira

que ela estava lá, foi aí que ela entrou.

Ok, então ela teve uma overdose e alguém jogou

o corpo na esperança de que ele flutuasse ou afundasse.

Lena: Então precisamos dos nomes de todos os passageiros.

e os tripulantes desse navio e de todos

os barcos nos berços de ambos os lados.

Comece com ele.

Lena: Por que ele?

DANNY: São os olhos.

Agora imagine isso com mais

cabelo e um colete ridículo.

E calças.

Sim, o guia turístico revolucionário, Tommy.

Eles o chamam de Ossos.

Começou a trabalhar com equipamentos de pesca com o pai.

Então, Bones trabalha no porto vestido como Sam Adams.

enquanto atira baleias assassinas em turistas ao mesmo tempo.

Faz sentido.

Base de clientes estável em busca de diversão.

Vamos falar com Bones.

Não há como um júri ignorar o passado de Harper no pornô.

Você é um promotor talentoso. Tem que haver um ângulo.

Não, eu vi os filmes. Está amarrado da mesma maneira

nas fitas que o acusado amarrou a ela durante o

agressão, e continua dizendo o quanto ele gosta disso.

Você investigou mais detalhadamente o acusado?

Alguma história de violência contra as mulheres?

Nada. Ele é um escoteiro.

Literalmente. Eu cheguei tão longe.

O homem é um Eagle Scout com um histórico muito claro.

Continue pesquisando.

O passado de Harper não deveria

impedi-lo de ver seu agressor punido.

Com todo o respeito, por que você insiste tanto nisso?

Já nos declaramos culpados de crimes sexuais como este antes.

Harper não violou nenhuma lei.

Da última vez que verifiquei, pornografia

Ainda é legal, então não vou

abandoná-la pelas decisões que ela tomou quando era

Muito jovem para realmente pensar nas consequências.

Bem, jovem ou não, a Internet é para sempre.

Infelizmente.

Ela usou um nome falso.

Ele cobriu a maior parte do rosto com uma venda, certo?

-BOM.

-Então, para começar, como a defesa encontrou o vídeo?

Envie-me esse vídeo.

Se não pudermos levar isto a tribunal, teremos de

encontrar uma maneira de chegar a um melhor

Eu concordo, e pode haver algo nesse filme. Eu acabei de...

-Eu tenho que ver por mim mesmo. -Ei...

Oh, pare de agarrar suas pérolas, Bobby.

Envie-me o vídeo.

Eu pensei que o tratamento do silêncio iria acabar

depois que deixamos Becky.

Pelo menos me diga se você está bem.

-Phoebe, olhe para mim. -Ou o quê?

Você vai me prender?

Isso foi muito embaraçoso.

Você ameaçou colocar meus amigos na prisão.

-Eu não consigo nem com você! -Você mentiu para mim!

E para quê?

Então você poderia beber vodca quente

para o parque e curtir com um cara mais velho

O que, aliás, nem era tão fofo assim?

Eu não estava bebendo e não estava namorando ele.

Mas você não saberia porque você também era

ocupado actuando como "Superintendente Save a Ho".

Fiquei apavorado!

Por 47 minutos, eu não tinha ideia

onde você estava ou o que estava acontecendo!

Eu vi coisas, Phoebe... coisas ruins...

e por um minuto pensei que poderia ser você.

Foi um dos piores sentimentos. Eu já tive isso.

Então sim, eu ameacei

prender seus amigos e

Fiquei muito envergonhado e faria de novo.

- -

Se o seu telefone fizer ping neste bloco,

Eu garanto para você. Os ossos estão lá.

Eu deveria entrar sozinho, disfarçado, manter a discrição.

Não, deveríamos bater nele com força e

rapidamente antes que você saiba o que está acontecendo.

Se você fizer isso, então todo viciado e traficante

Na cidade ele saberá que você está procurando por ele.

Você também pode jogar uma granada na caixa do DCU.

Bem, acho que não temos tempo para usar luvas de pelica agora.

Chega, chega, chega. Vocês dois estão errados.

Vamos em silêncio. E não tem como você entrar sozinho.

É perigoso.

Usamos coletes. E deixe-me falar.

Ok, mas tecnicamente, se ambos

estamos errados, isso significa que pelo menos

um de nós está certo. -Concordo.

Você poderia calar a boca?

♪

Ei, eu moro na mesma rua.

Você sabia que sai fumaça do seu telhado?

- -Mantenha as mãos juntas.

Pistola!

Eu acho que essa Glock

não está registrado para você,

Então você nos fará um favor e ficará de boca fechada.

e não deixe ninguém saber que estamos aqui.

Talvez possamos ajudá-lo a sair dessa.

Fumaça do telhado? Da última vez que verifiquei,

Você deveria se identificar. você mesmo como um policial.

O novo parceiro tem você

quebrando as regras? -Funcionou, não foi?

: Tudo bem.

Você não está em apuros.

Apenas nos diga onde está o Bones.

Estamos procurando ossos. Onde se encontra Ossos?

- -Ei, não. Ei.

É por isso que eu disse perfil discreto.

Somos policiais em uma casa de crack. Não existe tal coisa.

Lena: Aqui!

HOMEM: Cinco zero. A polícia está aqui.

-Fique aí. Você tem seus seis. -Nisso.

Acabou.

Droga.

DANNY: Este medalhão parece familiar.

Parece que alguém não queria que eu falasse.

DANNY: E esse alguém...

...poderia ser Sully.

JONÁS: Sim, Sra. Katz.

Nós vamos encontrar.

Bem. Tudo bem.

Sim, adeus.

Essa é sua namorada? Não, era a Sra. Katz ligando para saber se já havíamos encontrado Murray.

Aparentemente ele ainda não voltou para casa.

Ela teme que ele esteja com problemas.

Ele está com problemas. Ele é um jogador.

Ele faz quebra-cabeças com seu vizinho mais velho.

Ele não é o tipo de pessoa que para

voltar para casa sem motivo, e eu saberia.

- -Eu tenho a mesma edição

edição limitada de The Settlers of Catan que ele.

Bem, nós entendemos. Murray é o Sean do multiverso,

quem você teria sido se nunca tivesse se tornado um policial.

Não se preocupe, se ele estiver com problemas, nós o encontraremos.

SEAN: O que faz você pensar? A próxima pista está aqui, afinal?

Bem, foi isso que você disse: "The Harvard Garden".

"A água sussurra."

-“O olhar do professor.” -Hum-hmm.

Enquanto você estava ocupado consertando

Catan, eu estava aqui saindo com garotas.

Quem teria pensado que você era um romântico tão incurável?

Você sabe que o arboreto é gratuito, certo?

Algum encontro.

Tem uma placa aqui

para a professora de Helen Keller.

Ana Sullivan.

Ele usou água para ensinar Helen a falar. "A água sussurra"

.

Você sabe, há um belo banco de beijos lá. Agradável e tranquilo.

Oh, tudo bem.

-O que é isso? O que é isso? -Oh.

Vamos digitalizá-lo.

SEAN: Ah, é a próxima pista. O que isso significa?

Eu não faço ideia.

♪

Lena, você me conhece.

Por que estou aqui?

O que é isso? Isto é seu?

Onde você encontrou isso?

Com um traficante morto.

Um que ele vendeu para Kathy.

Tommy “Bones” Johnson.

Você tem que me contar agora mesmo o que está acontecendo, Sully.

Fui e conversei com meu antigo plug.

Perguntei a ele quem vendia drogas no porto.

Falei com ele.

Mas eu juro, eu não tinha ideia de que ele estava morto até agora.

Ele foi espancado até a morte por

alguém que sabia dar um soco.

Você não disse que começou

caixa depois de limpa?

Olhe para os nós dos seus dedos agora.

Tem certeza que eles acabaram de conversar?

Encontrei-o num quarto dos fundos. Eu estava todo assustado.

Ele estava com medo?

O que você quer dizer? Altamente tenso? Assustado?

Ritmo. Ele estava usando drogas.

Perguntei a ele sobre minha irmã.

Ele veio em minha direção. Ele deu o primeiro golpe.

Nós lutamos.

Juro por Deus, ele estava vivo quando saí.

Você tem que acreditar em mim.

Sully, há muitas evidências para não ficar com você.

Mas eu não fiz isso.

Por favor.

Eles vão levar meu filho. Não deixe que levem meu filho.

Tudo bem.

Se você está dizendo a verdade e realmente não fez isso...

...Vou garantir que você volte para casa, para seu filho.

♪

♪ Baruj é Adonai ♪

♪ Eloheinu melekh ha'olam ♪

♪ Hamotzi lechem min ha'aretz ♪

♪ Amém. ♪

-Tudo bem. -Vamos comer.

PHOEBE: Tudo parece tão delicioso.

Nada de telefones na mesa, por favor.

sara: Mamãe faz a melhor chalá.

Isso significa que você também, Sean.

MAE: Então, como foi o dia de todos?

No trabalho?

JONAS: Bom. Você pode passar a manteiga? MAE: Muito bem.

Não posso comer chalá sem manteiga. -SARAH: Mãe. -Hum-hmm?

Você se lembra do nosso primeiro jantar de Shabat juntos?

Claro. Eu não acredito Nunca

Tenho estado tão nervoso na minha vida.

Você estava nervoso? Eu não sabia. Porque?

Vir para o Shabat me fez sentir como se as coisas estivessem ficando reais.

E não finja que você também não pensou nisso.

da mesma forma, porque você estava bufando e bufando

bufando porque eu substituiria sua mãe.

Você até manchou o cobertor de chalá do seu pai.

Você fez isso?

-SARAH: Sim. -LENA: Ela fez.

Ele derrubou uma taça de vinho.

A feliz família mesclada tinha muito

drama nos bastidores. Quem sabia?

-Foi só no começo.

-SARAH: Sim, foi difícil no começo, mas depois ficou mais fácil.

Você sabe, Mae é a razão pela qual me tornei policial.

-Na verdade? -Hum-hmm.

Sim, um dia ela me levou para trabalhar com ela e

Um detetive entrou e eles estavam conversando sobre

um caso, e eu estava apenas olhando para eles.

Ambos eram tão inteligentes e tão poderosos,

e quando eles terminaram de conversar, eu sabia

exatamente o que eu queria ser quando crescesse.

Dizem que as alegrias da nossa infância tornam-se as nossas paixões adultas.

Não é mesmo, Sean?

O telefone.

É para um caso.

Um caso?

Tudo começou como um cheque de bem-estar e...

Um menino desapareceu enquanto procurava

um tesouro e estamos tentando resolvê-lo.

A última pista foi uma série de números que... não sei.

Você registrou uma denúncia de pessoa desaparecida?

Sim, mas esse cara, Murray Bennett, tem cerca de 20 anos.

Não há sinais de luta. Viva sozinho.

Ninguém vai se importar com o caso

pelas próximas 36 horas, então...

Bem, quais são os números? Talvez possamos ajudar.

Lena: Sim, estou com Phoebe.

Quais são os números?

Já descobrimos a primeira parte.

Colocamos a sequência em um gerador

de números de IA e surgiu como, Este

figura estranha para "bebê europeu". EU...

O que você está falando?

JONÁS: Bem, você está com sorte, porque há mais números.

Sete, 11 e 14.

Espere, "bebê europeu"

.

Talvez seja a palavra para "bebê" em outro

linguagem. “Criança” em espanhol – ou “dziecko” em polonês.

-LENA: Hum-hmm.

"Tinok" em hebraico, "criança" em francês.

Bebê? Criança.

Fãs do Red Sox. -Quero dizer, vamos. -

LENA: Claro.

Sim, Babe Ruth, o Grande Bambino, tocou

seu primeiro jogo com o Sox

Rojas -11 de julho de 1914. -LENA: Uau.

É isso nas últimas três edições.

Sara: Oh meu Deus. Claro.

Mãe.

Então isso significa que a próxima pista está no Fenway Park?

SEAN: Poderia ser. Pode ser na sua casa, no seu clube de charutos.

Você realmente nunca sabe com essas gincanas.

As pistas geralmente têm significados mais profundos.

Sim, o contexto é importante.

DANNY: Tente lembrar que o trabalho de

Um policial em patrulha deve responder e relatar.

E isso é tudo.

Pai...

É um jogo perigoso sair por aí fazendo

passar por detetive quando não estiver,

especialmente quando a vida de alguém está em jogo.

Portanto, tenha cuidado.

E talvez passe isso para seu chefe na próxima vez.

Bem, isso não é divertido.

Danny está certo.

Eu não acho que estou pronto para isso.

Você tinha 15 anos quando me casei com Ben.

E foi intimidante,

e eu já era mãe.

Ninguém nunca está preparado.

Sim, mas a maioria das pessoas tem alguns anos de

Pratique antes que a criança perceba o quão ruim ela está.

- -Ele escapou.

Encontrei-a no parque com álcool e rapazes.

O que você fez?

Ele fez uma ótima cena. Ele ameaçou prender as crianças.

-Porque? -Porque...

Eu estava morrendo de medo porque estava ferido.

Você será uma ótima mãe.

Madrasta.

Existe alguma diferença?

DANNY: Se você não se importa comigo

Eu perguntei, o que está acontecendo com você e seu ex-companheiro?

Vocês já namoraram antes ou algo assim?

-Não. -Mm.

Eu não queria colocar nossos

associação, então nunca saímos.

Mas ele quer?

-Sim. -Oh.

Por que você não dá uma chance?

Talvez funcione.

Você está me dando conselhos sobre relacionamento?

Não, não estou lhe dando conselhos.

Mas tenho um pouco de experiência no assunto.

Sim.

Bem, o que estamos fazendo aqui?

Não acho que Sully tenha feito isso.

Bom.

Na sala de interrogatório, ele disse

a verdade e disse que Bones era

nervoso e andava de um lado para o outro.

Eu não acho que Sully foi o único

O único que teve problemas com ele.

Bones vende as drogas para Kathy, Kathy tem

overdose, Bones joga seu corpo para cobri-lo.

Mas a polícia ainda encontra o pacote

da orca, o que provavelmente iria irritar...

-Chefe do Bones. -Chefe do Bones.

Mitchell Edgars.

Acho que foi ele quem matou

Bones, para limpar sua bagunça.

É uma boa teoria, mas como podemos vinculá-la a isso?

-Testemunhas. -

DANY: Com licença. Com licença.

Polícia.

Eu gostaria de fazer algumas perguntas. Lena: Sou o Detetive Silver.

Este é o detetive Reagan. Prazer em conhecê-lo.

Você esteve aqui ontem.

Você viu algo estranho?

Alguém que não vem regularmente?

Eles estão falando daquele helicóptero de ontem?

Porque... eu não fiz nada com a bicicleta daquele cara.

Alguém disse sim?

Posso dar uma olhada no seu telefone por um segundo?

-Não, eu... -Você não está com nenhum problema.

Tudo bem.

Eu só quero dar uma olhada

rapidamente, com sua permissão. -Tudo bem.

Tudo bem.

Ele parece o tipo que poderia aguentar

selfie se um helicóptero parasse legal.

Hummm. É preciso conhecer um, certo?

Justo.

PATINADOR: E-eu só estava...

Eu estava apenas posando.

Corri assim que saiu porque

Ele parecia irritado porque eu estava em seu

bicicleta, mas eu realmente não fiz nada.

Nós acreditamos em você.

Reconheço o helicóptero do arquivo do caso DCU.

E olhe lá.

Aproxime-se. Que é aquele?

DANNY: Bem, e o carimbo de data/hora é

três horas depois. Sully esteve aqui.

Mitchell Edgars.

Cuidado com seus passos.

Olá?

Cara, ontem à noite prometemos parar de caçar no jantar.

-Devíamos ir. -Não, não, não.

Este tem que ser o lugar, cara.

Como você estava dizendo, há sempre um

significado mais profundo para essas faixas.

Chegou esta manhã.

Sim, eu sei, você disse que encontrou o

números ao lado da placa de Anne Sullivan. -Uh-huh.

E Anne Sullivan ensinou Helen Keller.

SEAN: O que Babe Ruth vai fazer? Com Helen Keller?

"Helen" é a faixa.

Babe Ruth conheceu sua esposa Helen Woodford em 11 de julho de 1914.

Sete, 11, 14. Esses são os mesmos números novamente.

-Uh-huh. -Esse é o mesmo dia que Babe

Ruth -começou com o Red Sox.

-Uh-huh, e eles se conheceram aqui mesmo em Southie.

Costumava ser um café chamado Landers. Ela trabalhou aqui.

Então pode ser isso.

MURRAY: Socorro! Estou aqui embaixo!

-SEAN: Espere, você ouviu isso? -JONA: Sim.

-MURRAY: Socorro! -Está ali.

-SEAN: Polícia de Boston! - JONÁ: ¿Murray?

MURRAY: Sim! Sim! Estou aqui embaixo!

-Ajuda! -JONÁS: Está aí.

-Murray Bennett? -Sim. Como você me encontrou?

Acho que você poderia dizer que a Sra. Katz é real. Ok, cara, vou tentar entender isso, ok? Ah, acho que quebrei a perna e a mão.

-O que aconteceu?

-Eu estava olhando

o tesouro, e tudo caiu.

Eu acordei e

Eu estava preso aqui.

e meu telefone estava mudo.

Tudo bem. Você está seguro agora.

Este é Jonah Silver, BPD. Preciso do EMS na minha localização agora.

Apenas aguente firme, cara.

Tudo bem? A ajuda está a caminho.

Ei.

Ei, eu encontrei.

Ele encontrou o tesouro.

Isso significa que nós também fizemos isso.

♪

. -LENA: TPB! -OFICIAL: Mãos ao alto!

-Mãos ao alto! Não se mova! -LENA: Mãos ao alto!

Lena: TPB! Mãos ao alto! Ei, ei, ei!

Mãos ao alto! Mãos ao alto! Mitchell Edgars!

Está funcionando!

-RODGERS: Estou atrás dele! -LENA: Você acertou!

DANY: Vá. Te peguei.

Pistola.

Você está preso pelo assassinato.

por Tommy "Bones" Johnson,

distribuição de entorpecentes e

homicídio culposo na morte de Kathy Sullivan.

-EDGARS: Quero um advogado! -Vamos.

DANNY: Você vai precisar de um.

Suas impressões digitais estavam por todo o quarto do Bones.

EDGAR: Arranje-me um advogado!

DANY: Vamos. Vamos!

Estou feliz que você confiou em seus instintos sobre Sully.

Você estava certo.

Agora a pergunta é: você também vai

Confiar nos seus instintos sobre o Detetive Rodgers?

Uau, você está forçando isso. Porque?

Porque eu não acho que você tenha

medo de que não funcione com ele.

Eu acho que você está com medo de que funcione

com ele e você se arrependerá, assim como ele

cara saindo em um cruzeiro no porto.

Eu nem deveria ter te contado isso.

Bem, estou feliz que você tenha feito isso. Explica muito.

Como o que?

Por exemplo, por que um detetive brilhante como você

ainda está trabalhando para o detetive sargento.

Eu acho, não sei, o que você colocou

toda a sua carreira em espera por

ajudar você a fazer isso, não sei o quê,

Terminar a faculdade ou algo assim?

Bem, primeiro foi fazer um mochilão pela Europa.

Ah, pior ainda.

E foi depois da faculdade. Então

Voltamos para cá e adiei o ingresso na academia.

Eu fiz trabalhos diferentes

para ajudá-lo durante

seus estudos médicos.

E então ele conheceu alguém na residência.

Hum.

Então, você coloca seu propósito em espera por

alguém que você ama, você ingressou no departamento anos

depois da maioria das pessoas da sua idade e

agora você tem medo de se envolver com alguém porque

quem você pode ter sentimentos porque não quer se arrepender.

Eu entendo. Eu estive lá.

Você viajou pela Europa e ajudou

alguém para ir para a faculdade de medicina?

Não, eu não fiz isso.

Mas me recusei a sair com meu parceiro,

embora obviamente houvesse sentimentos ali.

Mas depois da minha morte

esposa, eu estava com medo de me machucar novamente.

E eu não queria me arrepender.

O que mudou?

Um homem muito sábio me deu um

Conselho muito sábio e eu realmente o segui.

E não me arrependo.

Mas isso não é sobre mim.

É sobre você.

Você está bem?

-Sim. Você? -Sim.

Como nos velhos tempos, hein?

-Vamos a julgamento? -MAE: Não.

Mas o agressor dela será um criminoso sexual

registrado e cumprirá uma pena grave de prisão.

Que? Como?

Bem, uh... Aqui, sente-se.

Alguém me disse que muitas vezes voltamos para

as alegrias da infância como paixões adultas.

Seu atacante era um Eagle Scout.

Ele usou o que é chamado de nó de luta livre em você.

Fácil de aprender se você for um Eagle Scout.

Agora, quando vi o nó daquele lutador no

vista, percebi que devo ter visto

seu filme antigo para saber que nó dar.

Pesquisamos e encontramos o seu

Endereço IP em logs da web.

Então ele estava copiando o pornô que eu fiz?

Seu endereço IP visitou o site 642 vezes.

Ele estava obcecado e até escreveu estes

comentários anônimos fantasiando sobre o que

ia fazer, o que demonstrava intenção.

Mas pensei que teria que testemunhar

para ter certeza de que não foi fácil.

Quando apresentamos novas evidências

ao advogado adversário, eles aceitaram o acordo.

18 anos de prisão estadual, entrada

no registro de agressores sexuais.

E minha história não será divulgada?

Sua história está segura.

Ah...

Você venceu.

Obrigada.

Obrigado por não desistir de mim.

Obrigado por ter vindo.

Quero que você saiba que não estou tentando substituir sua mãe.

Temos um relacionamento muito diferente.

Eu entendo isso mais do que você pensa.

Esqueci que você também tinha uma madrasta.

Eu me importo com você e estou apaixonada pelo seu pai.

Então... você terá que se acostumar

para eu estar na sua vida, ok?

Ele teve outras namoradas.

Sim, mas nenhum deles gosta de você.

-Você voltou mais cedo?

-Sim, e você sentiu falta da primeira gangue da minha filha?

É como um evento único na vida.

É isso que é, certo?

PHOEBE: Vocês são tão fofos.

-É nojento. -SETH: Isto é para você.

-Bem? -Você sabia?

Dê-me um desses.

-Sim? -Sim.

Estamos todos juntos nisso, certo?

Bem, quero dizer, eu não fiz nada.

Oh, tudo bem. Bem, você pode continuar

vá em frente e me conte sobre tudo

aquelas namoradas de quem Phoebe fala.

Não, isso não importa. Você sabia? Estou dentro.

Espero que esteja tudo bem com você

Phoebe se junta à limpeza do parque.

Ah, você está brincando comigo? Acho que é um ótimo castigo.

Ei, hein...

Então, estive pensando.

Acho que é hora de tornarmos isso um pouco mais oficial.

Se você me propor com

aquele colete enquanto segura

sacos de lixo, -Eu... -Oh, oh.

Vamos passo a passo.

Quero que você more comigo.

Bem, conosco.

Você sabe, teríamos Phoebe a cada duas semanas.

Esse é um grande passo.

¿Está seguro?

Você dorme o tempo todo.

Eu odeio quando você vai embora. Você é fantástico com Phoebe.

Eu sinto que as coisas estão indo bem.

Não é?

-Sim. Sim. -Sim?

♪ Encontre algo em que você possa se agarrar ♪

♪ Encontre alguém que estará ao seu lado ♪

♪ Porque isso é tudo que realmente importa no final ♪

DANY: Aí está.

Ah, Sully.

Você vai para casa.

O que aconteceu? Você resolveu o caso?

Pegamos o cara que matou Bones

e a DCU acrescentará acusações de drogas.

O que também significa que obtemos

da rua as drogas que mataram Kathy.

Isso é bom. Isso é muito bom.

Você quebrou a corrente, Sully.

Vá ficar com seu filho.

Venha aqui.

♪ é amor, amor, amor ♪

♪ Amor, amor, amor ♪

♪ Porque isso é tudo que realmente importa... ♪

Obrigada.

DANNY: Sim.

Você vem comemorar?

Na verdade, vim trazer isso para você.

É para sua mesa, Reagan.

Uau, um presente para minha garotinha.

Na verdade, é para mim.

A regra é que você coloque na gaveta de cima.

Se eu pedir um, você joga para mim.

Se eu pedir dois...

RODGERS: Não, não faça isso.

Você não pode confiar nela.

Mas eu, ah...

Eu confio nela para você, Reagan.

Hum.

Mesmo que você não seja minha vibe.

Sou um gosto adquirido.

Ei, sobre aquela coisa que você me perguntou...

Cachorro?

Pergunte-me novamente.

E o que vocês dois estão fazendo aqui?

Vim dizer que encontramos Murray Bennett.

Ele ficará bem.

E encontramos o tesouro.

Eu sei que desobedeci, mas estava certo, pai.

Eu precisava de ajuda.

Olha, como pai, estou orgulhoso por vocês dois terem salvado uma vida.

Mas, como policial, você não pode perder a cabeça.

E você o fará se não tomar cuidado.

- -Estarei observando vocês dois.

Sim, senhor. Ei, Sean, temos que ir à delegacia.

Sim.

O que você teria feito?

Eu teria feito o mesmo que você.

Só não faça disso um hábito.

♪

- -

DANNY: Bem, olá, linda.

-Ei. -Olá.

Eu deveria saber que você estaria trabalhando em um caso.

Acabei de bater, então serei todo seu o fim de semana inteiro.

Poderei conhecer seu novo parceiro?

Eh...

Acho que ela está um pouco ocupada agora.

-Oh. -Hum-hmm.

Esse é seu antigo parceiro?

-Você a convidou para sair? -Hum-hmm. Hummm.

E acho que ela disse sim.

Ah, estou feliz por eles.

Sim, eu também.

-Oh, Deus, senti sua falta. -

Legendas patrocinadas

pela CBS e TOYOTA.

Legendado por Media Access Group em WGBH acceso.wgbh.org

CRIANÇAS: Os Brandons.

Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.